MBMedia class

This class represents a media in MBurger.

Constructors

MBMedia({required Map<String, dynamic> dictionary})
Initializes a file with the dictionary returned by the MBurger APIs.

Properties

fileName ↔ String
The file name of the media
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
The id of the file.
getter/setter pair
mimeType ↔ String
The MIME type of the media.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
The size of the image.
getter/setter pair
url ↔ String
The url of the media.
getter/setter pair
uuid ↔ String
The uuid of this image in the media center.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited