MBMediaElement class

This class represents a MBurger media element.

Inheritance

Constructors

MBMediaElement({required Map<String, dynamic> dictionary})
Initializes a media element with the dictionary returned by the MBurger APIs.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
The id of the element.
finalinherited
media ↔ List<MBMedia>
The media of the element.
getter/setter pair
mediaType ↔ MBMediaType
The type of media.
getter/setter pair
order → int
The order of the element.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MBElementType
The type of the element.
finalinherited

Methods

firstMedia() → MBMedia?
The first media of the element if exists, null otherwise.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited