MBPollElement class

This class represents a MBurger poll element, the property answers contains the answers the user can give to a the poll.

Inheritance

Constructors

MBPollElement({required Map<String, dynamic> dictionary})
Initializes a poll element with the dictionary returned by the MBurger APIs.
factory

Properties

answer → MBPollAnswer?
The answer.
final
answered → bool
If the current user/device has answered.
final
answers → List<MBPollAnswer>
The possible answers for the poll.
final
expiration → DateTime?
The expiration date of the poll.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The id of the element.
finalinherited
order → int
The order of the element.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MBElementType
The type of the element.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited