MBUploadableElement class

Implementers

Constructors

MBUploadableElement(String localeIdentifier, String elementName)
Initializes an uploadable element with a locale identifier and a name

Properties

elementName → String
The name/key of the element.
final
hashCode → int
The hash code for this object.
no setterinherited
localeIdentifier → String
The locale of the element. This is needed to construct the parameter name.
final
parameterName → String
The name of the element, used when the element will be passed to the api.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toForm() → List<MBMultipartForm>?
Converts the element to an array of MBMultipartForm representing it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited