MBSection class

This class represents an MBurger section.

Constructors

MBSection({required int id, required int order, required Map<String, MBElement> elements, required DateTime availableAt, required bool inEvidence})
Initializes a MBSection with all its data
MBSection.fromDictionary(Map<String, dynamic> dictionary)
Initializes a section with the dictionary returned by the api.
factory

Properties

availableAt → DateTime
The date the section is available.
final
elements → Map<String, MBElement>
The elements of the section. The key of the dictionary is the name of the element, the value is an instance of a MBElement that represents the object.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The id of the section.
final
inEvidence → bool
Indicates if the section is in evidence.
final
order → int
The order of the section.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited