MBSortParameter class

A parameter used to sort the elements that will be returned.

Inheritance

Constructors

MBSortParameter({required String field, bool ascending = true})
Initializes a MBSortParameter with the filed and ascending value (defaults to true).

Properties

ascending → bool
If the elements should be sorted in ascending order.
final
field → String
The filed of the element used to sort.
final
hashCode → int
The hash code for this object.
no setterinherited
representation → Map<String, String>
The representation of this parameter, how it will be passed to MBurger APIs.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited