MBProject class

Represents a MBurger project.

Constructors

MBProject({required int id, required String name, required List<MBContract>? contracts})
Initializes a MBProject with all its variables
MBProject.fromDictionary(Map<String, dynamic> dictionary)
Initializes a project with the dictionary returned by the MBurger APIs.
factory

Properties

contracts → List<MBContract>?
The legal contracts of the project.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The id of the project.
final
name → String
The name of the project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited